{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "GATK4: Mark Duplicates",
            "doc": "MarkDuplicates (Picard): Identifies duplicate reads.\n\nThis tool locates and tags duplicate reads in a BAM or SAM file, where duplicate reads are \ndefined as originating from a single fragment of DNA. Duplicates can arise during sample \npreparation e.g. library construction using PCR. See also EstimateLibraryComplexity for \nadditional notes on PCR duplication artifacts. Duplicate reads can also result from a single \namplification cluster, incorrectly detected as multiple clusters by the optical sensor of the \nsequencing instrument. These duplication artifacts are referred to as optical duplicates.\n\nThe MarkDuplicates tool works by comparing sequences in the 5 prime positions of both reads \nand read-pairs in a SAM/BAM file. An BARCODE_TAG option is available to facilitate duplicate\nmarking using molecular barcodes. After duplicate reads are collected, the tool differentiates \nthe primary and duplicate reads using an algorithm that ranks reads by the sums of their \nbase-quality scores (default method).\n\nThe tool's main output is a new SAM or BAM file, in which duplicates have been identified \nin the SAM flags field for each read. Duplicates are marked with the hexadecimal value of 0x0400, \nwhich corresponds to a decimal value of 1024. If you are not familiar with this type of annotation, \nplease see the following blog post for additional information.\n\nAlthough the bitwise flag annotation indicates whether a read was marked as a duplicate, \nit does not identify the type of duplicate. To do this, a new tag called the duplicate type (DT) \ntag was recently added as an optional output in the 'optional field' section of a SAM/BAM file. \nInvoking the TAGGING_POLICY option, you can instruct the program to mark all the duplicates (All), \nonly the optical duplicates (OpticalOnly), or no duplicates (DontTag). The records within the \noutput of a SAM/BAM file will have values for the 'DT' tag (depending on the invoked TAGGING_POLICY), \nas either library/PCR-generated duplicates (LB), or sequencing-platform artifact duplicates (SQ). \nThis tool uses the READ_NAME_REGEX and the OPTICAL_DUPLICATE_PIXEL_DISTANCE options as the \nprimary methods to identify and differentiate duplicate types. Set READ_NAME_REGEX to null to \nskip optical duplicate detection, e.g. for RNA-seq or other data where duplicate sets are \nextremely large and estimating library complexity is not an aim. Note that without optical \nduplicate counts, library size estimation will be inaccurate.\n\nMarkDuplicates also produces a metrics file indicating the numbers \nof duplicates for both single- and paired-end reads.\n\nThe program can take either coordinate-sorted or query-sorted inputs, however the behavior \nis slightly different. When the input is coordinate-sorted, unmapped mates of mapped records \nand supplementary/secondary alignments are not marked as duplicates. However, when the input \nis query-sorted (actually query-grouped), then unmapped mates and secondary/supplementary \nreads are not excluded from the duplication test and can be marked as duplicate reads.\n\nIf desired, duplicates can be removed using the REMOVE_DUPLICATE and REMOVE_SEQUENCING_DUPLICATES options.",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.3.0"
                }
            ],
            "inputs": [
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/bam",
                    "label": "bam",
                    "doc": "One or more input SAM or BAM files to analyze. Must be coordinate sorted.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 10
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/outputFilename",
                    "label": "outputFilename",
                    "doc": "File to write duplication metrics to",
                    "type": [
                        "string",
                        "null"
                    ],
                    "default": "generated.markduped.bam",
                    "inputBinding": {
                        "prefix": "-O",
                        "position": 10
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/metricsFilename",
                    "label": "metricsFilename",
                    "doc": "The output file to write marked records to.",
                    "type": [
                        "string",
                        "null"
                    ],
                    "default": "generated.metrics.txt",
                    "inputBinding": {
                        "prefix": "-M",
                        "position": 10
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/javaOptions",
                    "label": "javaOptions",
                    "type": [
                        {
                            "type": "array",
                            "items": "string"
                        },
                        "null"
                    ]
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/compression_level",
                    "label": "compression_level",
                    "doc": "Compression level for all compressed files created (e.g. BAM and VCF). Default value: 2.",
                    "type": [
                        "int",
                        "null"
                    ]
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/argumentsFile",
                    "label": "argumentsFile",
                    "doc": "read one or more arguments files and add them to the command line",
                    "type": [
                        {
                            "type": "array",
                            "items": "File"
                        },
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--arguments_file",
                        "position": 10
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/assumeSortOrder",
                    "label": "assumeSortOrder",
                    "doc": "If not null, assume that the input file has this order even if the header says otherwise. Exclusion: This argument cannot be used at the same time as ASSUME_SORTED. The --ASSUME_SORT_ORDER argument is an enumerated type (SortOrder), which can have one of the following values: [unsorted, queryname, coordinate, duplicate, unknown]",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-ASO"
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/barcodeTag",
                    "label": "barcodeTag",
                    "doc": "Barcode SAM tag (ex. BC for 10X Genomics)",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--BARCODE_TAG"
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/comment",
                    "label": "comment",
                    "doc": "Comment(s) to include in the output file's header.",
                    "type": [
                        {
                            "type": "array",
                            "items": "string"
                        },
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-CO"
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/createIndex",
                    "label": "createIndex",
                    "doc": "Whether to create a BAM index when writing a coordinate-sorted BAM file.",
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "--CREATE_INDEX",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/createMd5File",
                    "label": "createMd5File",
                    "doc": "Whether to create an MD5 digest for any BAM or FASTQ files created.",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--CREATE_MD5_FILE",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/maxRecordsInRam",
                    "label": "maxRecordsInRam",
                    "doc": "When writing SAM files that need to be sorted, this will specify the number of records stored in RAM before spilling to disk. Increasing this number reduces the number of file handles needed to sort a SAM file, and increases the amount of RAM needed.",
                    "type": [
                        "int",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--MAX_RECORDS_IN_RAM",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/quiet",
                    "label": "quiet",
                    "doc": "Whether to suppress job-summary info on System.err.",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--QUIET",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/tmpDir",
                    "label": "tmpDir",
                    "doc": "Undocumented option",
                    "type": "string",
                    "default": "tmp/",
                    "inputBinding": {
                        "prefix": "--TMP_DIR",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/useJdkDeflater",
                    "label": "useJdkDeflater",
                    "doc": "Whether to use the JdkDeflater (as opposed to IntelDeflater)",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--use_jdk_deflater",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/useJdkInflater",
                    "label": "useJdkInflater",
                    "doc": "Whether to use the JdkInflater (as opposed to IntelInflater)",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--use_jdk_inflater",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/validationStringency",
                    "label": "validationStringency",
                    "doc": "Validation stringency for all SAM files read by this program. Setting stringency to SILENT can improve performance when processing a BAM file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.The --VALIDATION_STRINGENCY argument is an enumerated type (ValidationStringency), which can have one of the following values: [STRICT, LENIENT, SILENT]",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--VALIDATION_STRINGENCY",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/verbosity",
                    "label": "verbosity",
                    "doc": "The --verbosity argument is an enumerated type (LogLevel), which can have one of the following values: [ERROR, WARNING, INFO, DEBUG]",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--verbosity",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/opticalDuplicatePixelDistance",
                    "label": "opticalDuplicatePixelDistance",
                    "doc": "The maximum offset between two duplicate clusters in order to consider them optical duplicates. The default is appropriate for unpatterned versions of the Illumina platform. For the patterned flowcell models, 2500 is more appropriate. For other platforms and models, users should experiment to find what works best.",
                    "type": [
                        "int",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--OPTICAL_DUPLICATE_PIXEL_DISTANCE"
                    }
                }
            ],
            "stdout": "_stdout",
            "stderr": "_stderr",
            "baseCommand": [
                "gatk",
                "MarkDuplicates"
            ],
            "arguments": [
                {
                    "prefix": "--java-options",
                    "position": -1,
                    "valueFrom": "$(\"-Xmx{memory}G {compression} {otherargs}\".replace(/\\{memory\\}/g, (([inputs.runtime_memory, 8, 4].filter(function (inner) { return inner != null })[0] * 3) / 4)).replace(/\\{compression\\}/g, (inputs.compression_level != null) ? (\"-Dsamjdk.compress_level=\" + inputs.compression_level) : \"\").replace(/\\{otherargs\\}/g, [inputs.javaOptions, []].filter(function (inner) { return inner != null })[0].join(\" \")))"
                }
            ],
            "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl",
            "outputs": [
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/out",
                    "label": "out",
                    "type": "File",
                    "secondaryFiles": [
                        "${\n\n        function resolveSecondary(base, secPattern) {\n          if (secPattern[0] == \"^\") {\n            var spl = base.split(\".\");\n            var endIndex = spl.length > 1 ? spl.length - 1 : 1;\n            return resolveSecondary(spl.slice(undefined, endIndex).join(\".\"), secPattern.slice(1));\n          }\n          return base + secPattern\n        }\n        return [\n                {\n                    path: resolveSecondary(self.path, \"^.bai\"),\n                    basename: resolveSecondary(self.basename, \".bai\"),\n                    class: \"File\",\n                }\n        ];\n\n}"
                    ],
                    "outputBinding": {
                        "glob": "generated.markduped.bam",
                        "loadContents": false
                    }
                },
                {
                    "id": "#Gatk4MarkDuplicates_4_1_3_0.cwl/Gatk4MarkDuplicates/metrics",
                    "label": "metrics",
                    "type": "File",
                    "outputBinding": {
                        "glob": "generated.metrics.txt",
                        "loadContents": false
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "GATK4: Merge SAM Files",
            "doc": "Merges multiple SAM/BAM files into one file",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.3.0"
                }
            ],
            "inputs": [
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/javaOptions",
                    "label": "javaOptions",
                    "type": [
                        {
                            "type": "array",
                            "items": "string"
                        },
                        "null"
                    ]
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/compression_level",
                    "label": "compression_level",
                    "doc": "Compression level for all compressed files created (e.g. BAM and VCF). Default value: 2.",
                    "type": [
                        "int",
                        "null"
                    ]
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/bams",
                    "label": "bams",
                    "doc": "The SAM/BAM file to sort.",
                    "type": {
                        "type": "array",
                        "inputBinding": {
                            "prefix": "-I"
                        },
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 10
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/sampleName",
                    "label": "sampleName",
                    "doc": "Used for naming purposes only",
                    "type": [
                        "string",
                        "null"
                    ]
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/outputFilename",
                    "label": "outputFilename",
                    "doc": "SAM/BAM file to write merged result to",
                    "type": [
                        "string",
                        "null"
                    ],
                    "default": "generated.merged.bam",
                    "inputBinding": {
                        "prefix": "-O",
                        "position": 10,
                        "valueFrom": "$(inputs.sampleName ? inputs.sampleName : \"generated\").merged.bam"
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/argumentsFile",
                    "label": "argumentsFile",
                    "doc": "read one or more arguments files and add them to the command line",
                    "type": [
                        {
                            "type": "array",
                            "items": "File"
                        },
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--arguments_file",
                        "position": 10
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/assumeSorted",
                    "label": "assumeSorted",
                    "doc": "If true, assume that the input files are in the same sort order as the requested output sort order, even if their headers say otherwise.",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-AS"
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/comment",
                    "label": "comment",
                    "doc": "Comment(s) to include in the merged output file's header.",
                    "type": [
                        {
                            "type": "array",
                            "items": "string"
                        },
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-CO"
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/mergeSequenceDictionaries",
                    "label": "mergeSequenceDictionaries",
                    "doc": "Merge the sequence dictionaries",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-MSD"
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/sortOrder",
                    "label": "sortOrder",
                    "doc": "The --SORT_ORDER argument is an enumerated type (SortOrder), which can have one of the following values: [unsorted, queryname, coordinate, duplicate, unknown]",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-SO",
                        "position": 10
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/useThreading",
                    "label": "useThreading",
                    "doc": "Option to create a background thread to encode, compress and write to disk the output file. The threaded version uses about 20% more CPU and decreases runtime by ~20% when writing out a compressed BAM file.",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--USE_THREADING"
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/compressionLevel",
                    "label": "compressionLevel",
                    "doc": "Compression level for all compressed files created (e.g. BAM and GELI).",
                    "type": [
                        "int",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--COMPRESSION_LEVEL",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/createIndex",
                    "label": "createIndex",
                    "doc": "Whether to create a BAM index when writing a coordinate-sorted BAM file.",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--CREATE_INDEX",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/createMd5File",
                    "label": "createMd5File",
                    "doc": "Whether to create an MD5 digest for any BAM or FASTQ files created.",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--CREATE_MD5_FILE",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/maxRecordsInRam",
                    "label": "maxRecordsInRam",
                    "doc": "When writing SAM files that need to be sorted, this will specify the number of records stored in RAM before spilling to disk. Increasing this number reduces the number of file handles needed to sort a SAM file, and increases the amount of RAM needed.",
                    "type": [
                        "int",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--MAX_RECORDS_IN_RAM",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/quiet",
                    "label": "quiet",
                    "doc": "Whether to suppress job-summary info on System.err.",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--QUIET",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/reference",
                    "label": "reference",
                    "doc": "Reference sequence file.",
                    "type": [
                        "File",
                        "null"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--reference",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/tmpDir",
                    "label": "tmpDir",
                    "doc": "Undocumented option",
                    "type": "string",
                    "default": "/tmp/",
                    "inputBinding": {
                        "prefix": "--TMP_DIR",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/useJdkDeflater",
                    "label": "useJdkDeflater",
                    "doc": "Whether to use the JdkDeflater (as opposed to IntelDeflater)",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--use_jdk_deflater",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/useJdkInflater",
                    "label": "useJdkInflater",
                    "doc": "Whether to use the JdkInflater (as opposed to IntelInflater)",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--use_jdk_inflater",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/validationStringency",
                    "label": "validationStringency",
                    "doc": "Validation stringency for all SAM files read by this program. Setting stringency to SILENT can improve performance when processing a BAM file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.The --VALIDATION_STRINGENCY argument is an enumerated type (ValidationStringency), which can have one of the following values: [STRICT, LENIENT, SILENT]",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--VALIDATION_STRINGENCY",
                        "position": 11
                    }
                },
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/verbosity",
                    "label": "verbosity",
                    "doc": "The --verbosity argument is an enumerated type (LogLevel), which can have one of the following values: [ERROR, WARNING, INFO, DEBUG]",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--verbosity",
                        "position": 11
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl/Gatk4MergeSamFiles/out",
                    "label": "out",
                    "type": "File",
                    "secondaryFiles": [
                        "${\n\n        function resolveSecondary(base, secPattern) {\n          if (secPattern[0] == \"^\") {\n            var spl = base.split(\".\");\n            var endIndex = spl.length > 1 ? spl.length - 1 : 1;\n            return resolveSecondary(spl.slice(undefined, endIndex).join(\".\"), secPattern.slice(1));\n          }\n          return base + secPattern\n        }\n        return [\n                {\n                    path: resolveSecondary(self.path, \"^.bai\"),\n                    basename: resolveSecondary(self.basename, \".bai\"),\n                    class: \"File\",\n                }\n        ];\n\n}"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.sampleName ? inputs.sampleName : \"generated\").merged.bam",
                        "loadContents": false
                    }
                }
            ],
            "stdout": "_stdout",
            "stderr": "_stderr",
            "baseCommand": [
                "gatk",
                "MergeSamFiles"
            ],
            "arguments": [
                {
                    "prefix": "--java-options",
                    "position": -1,
                    "valueFrom": "$(\"-Xmx{memory}G {compression} {otherargs}\".replace(/\\{memory\\}/g, (([inputs.runtime_memory, 8, 4].filter(function (inner) { return inner != null })[0] * 3) / 4)).replace(/\\{compression\\}/g, (inputs.compression_level != null) ? (\"-Dsamjdk.compress_level=\" + inputs.compression_level) : \"\").replace(/\\{otherargs\\}/g, [inputs.javaOptions, []].filter(function (inner) { return inner != null })[0].join(\" \")))"
                }
            ],
            "id": "#Gatk4MergeSamFiles_4_1_3_0.cwl"
        },
        {
            "class": "Workflow",
            "label": "Merge and Mark Duplicates",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/bams",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ]
                },
                {
                    "id": "#main/createIndex",
                    "type": "boolean",
                    "default": true
                },
                {
                    "id": "#main/maxRecordsInRam",
                    "type": "int",
                    "default": 5000000
                },
                {
                    "id": "#main/sampleName",
                    "type": [
                        "string",
                        "null"
                    ]
                },
                {
                    "id": "#main/mergeSamFiles_useThreading",
                    "doc": "Option to create a background thread to encode, compress and write to disk the output file. The threaded version uses about 20% more CPU and decreases runtime by ~20% when writing out a compressed BAM file.",
                    "type": "boolean",
                    "default": true
                },
                {
                    "id": "#main/mergeSamFiles_validationStringency",
                    "doc": "Validation stringency for all SAM files read by this program. Setting stringency to SILENT can improve performance when processing a BAM file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.The --VALIDATION_STRINGENCY argument is an enumerated type (ValidationStringency), which can have one of the following values: [STRICT, LENIENT, SILENT]",
                    "type": "string",
                    "default": "SILENT"
                }
            ],
            "outputs": [
                {
                    "id": "#main/out",
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputSource": "#main/markDuplicates/out"
                }
            ],
            "steps": [
                {
                    "id": "#main/mergeSamFiles",
                    "label": "GATK4: Merge SAM Files",
                    "in": [
                        {
                            "id": "#main/mergeSamFiles/bams",
                            "source": "#main/bams"
                        },
                        {
                            "id": "#main/mergeSamFiles/sampleName",
                            "source": "#main/sampleName"
                        },
                        {
                            "id": "#main/mergeSamFiles/useThreading",
                            "source": "#main/mergeSamFiles_useThreading"
                        },
                        {
                            "id": "#main/mergeSamFiles/createIndex",
                            "source": "#main/createIndex"
                        },
                        {
                            "id": "#main/mergeSamFiles/maxRecordsInRam",
                            "source": "#main/maxRecordsInRam"
                        },
                        {
                            "id": "#main/mergeSamFiles/validationStringency",
                            "source": "#main/mergeSamFiles_validationStringency"
                        }
                    ],
                    "run": "#Gatk4MergeSamFiles_4_1_3_0.cwl",
                    "out": [
                        {
                            "id": "#main/mergeSamFiles/out"
                        }
                    ]
                },
                {
                    "id": "#main/markDuplicates",
                    "label": "GATK4: Mark Duplicates",
                    "in": [
                        {
                            "id": "#main/markDuplicates/bam",
                            "source": [
                                "#main/mergeSamFiles/out"
                            ],
                            "linkMerge": "merge_nested"
                        },
                        {
                            "id": "#main/markDuplicates/createIndex",
                            "source": "#main/createIndex"
                        },
                        {
                            "id": "#main/markDuplicates/maxRecordsInRam",
                            "source": "#main/maxRecordsInRam"
                        }
                    ],
                    "run": "#Gatk4MarkDuplicates_4_1_3_0.cwl",
                    "out": [
                        {
                            "id": "#main/markDuplicates/out"
                        },
                        {
                            "id": "#main/markDuplicates/metrics"
                        }
                    ]
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
